import { type To } from 'react-router'

const params = new URLSearchParams(window.location.search)
const experimentId = params.get('experiment_id') || '7028276368903241728'

export const getDefaultSearchParams = (): Record<string, string> => ({
  experiment_id: experimentId,
})

export const mergeSearchParams = (baseParams: URLSearchParams, defaultParams: Record<string, string>): string => {
  const merged = new URLSearchParams(baseParams)
  Object.entries(defaultParams).forEach(([key, value]) => {
    if (!merged.has(key)) {
      merged.set(key, value)
    }
  })
  return `?${merged.toString()}`
}

export const resolveTo = (to: To, defaultParams = getDefaultSearchParams()): To => {
  if (typeof to === 'string') {
    const [pathname, search = ''] = to.split('?')
    const baseParams = new URLSearchParams(search)
    const mergedSearch = mergeSearchParams(baseParams, defaultParams)
    return `${pathname}${mergedSearch}`
  } else {
    const baseParams = new URLSearchParams(to.search || '')
    const mergedSearch = mergeSearchParams(baseParams, defaultParams)
    return { ...to, search: mergedSearch }
  }
}
